@@ -1,5 +1,5 @@
 """
-# [LabML Neural Networks](index.html)
+# [labml.ai Neural Networks](index.html)
 
 This is a collection of simple PyTorch implementations of
 neural networks and related algorithms.
@@ -19,6 +19,7 @@ implementations.
 * [Transformer building blocks](transformers/models.html)
 * [Transformer XL](transformers/xl/index.html)
     * [Relative multi-headed attention](transformers/xl/relative_mha.html)
+* [Compressive Transformer](transformers/compressive/index.html)
 * [GPT Architecture](transformers/gpt/index.html)
 * [GLU Variants](transformers/glu_variants/simple.html)
 * [kNN-LM: Generalization through Memorization](transformers/knn/index.html)
@@ -75,7 +76,7 @@ If you use LabML for academic research, please cite the library using the follow
  author = {Varuna Jayasiri, Nipun Wijerathne},
  title = {LabML: A library to organize machine learning experiments},
  year = {2020},
- url = {https://lab-ml.com/},
+ url = {https://nn.labml.ai/},
 }
 ```
 """
